#
# spec file for package leafnode
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define spooldir    %{_localstatedir}/spool/news
%define confdir     %{_sysconfdir}/leafnode
%define runas_user  news
%define runas_group news
%define admin_user  newsadmin
%define admin_group newsadmin
%define upname leafnode
Name:           %{upname}
Version:        2.0.0~git.1745443528.0925b70
Release:        1.1
Summary:        Leaf site NNTP server
License:        MIT
Summary(de):    Ein offline-Newsserver
URL:            http://www.dt.e-technik.uni-dortmund.de/~ma/leafnode/beta/
# Use checkout from the git repo at
# https://gitlab.com/leafnode-2/leafnode-2/
Source0:        %{name}-%{version}.tar.xz
Source1:        README-SUSE.md
# PATCH-FEATURE-OPENSUSE harden_leafnode@.service.patch bsc#1181400 mcepl@suse.com
# https://en.opensuse.org/openSUSE:Security_Features#Systemd_hardening_effort
Patch0:         harden_leafnode@.service.patch
BuildRequires:  autoconf >= 2.68
BuildRequires:  automake
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pandoc
BuildRequires:  pam-devel
BuildRequires:  pcre2-devel
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  shadow
BuildRequires:  pkgconfig(systemd)
Requires(post): coreutils
Requires(post): systemd
Requires(postun): systemd
Requires(pre):  permissions
Requires(pre):  shadow
Requires(preun): systemd
# Because of moderators(5) manpage, and really these two
# shouldn't be on one system at once.
Conflicts:      inn
Obsoletes:      leafnode < %{version}
Provides:       leafnode = %{version}-%{release}
#
Provides:       user(%runas_user)
Provides:       group(%admin_group)
Provides:       group(%runas_group)
Provides:       user(%admin_user)
# For postfix
Requires(pre):  (group(maildrop) and postfix)

%description
Leafnode is a small NNTP server for leaf sites without permanent
connection to the internet. It supports a subset of NNTP and is able to
automatically fetch the newsgroups the user reads regularly from the
newsserver of the ISP and additionally offer local (site-specific)
groups to a LAN.

%description -l de
Leafnode ist ein offline-Newsserver, der vor allem für den typischen
Einzelnutzer-Rechner ohne permanente Internetanbindung geeignet ist.
Leafnode bezieht automatisch die Newsgroups, die der oder die Nutzer
regelmäßig lesen, vom Newsserver des Providers. Weiter erlaubt es, lokale
(Standort-spezifische) Newsgruppen im LAN anzubieten.

%prep
%autosetup -p1 -n %{name}-%{version}

autoreconf -v -f -i

cp -p %{SOURCE1} .

%build
%configure \
 --disable-silent-rules \
 --enable-spooldir=%{spooldir} \
 --enable-runas-user=$(id -un) \
 --sysconfdir=%{_sysconfdir}/%{upname} --with-pam
%make_build

%check
%make_build check README.html README

%install
# first clean out any prior aborted runs
%make_install

# We actually do not want filters to be installed in /etc/leafnode
rm %{buildroot}/%{_sysconfdir}/leafnode/filters*

# install systemd units
install -D -m 644 -t %{buildroot}%{_unitdir} systemd/*

for file in %{buildroot}/%{_sysconfdir}/leafnode/*.example ; do
   NEWFN=$(basename $file .example);
   mv $file %{buildroot}/%{_sysconfdir}/leafnode/$NEWFN
done

# When building without runas_user, then we need to set this
# parameter explicitly.
sed -i -e "s/^#\s*run_as_user.*\$/run_as_user = %{runas_user}/" \
    %{buildroot}/%{_sysconfdir}/leafnode/config

cat >%{buildroot}/%{_sysconfdir}/leafnode/local.groups << EOS
# List of all local groups
# The format of the file containing the local groups is
# news.group.name[tab]status[tab]Description
# where
# status could be y, n, or m letter, where
# y - "Local postings are allowed",
# m - "The group is moderated and all postings must be approved.",
# n - "No local postings are allowed, only articles from peers."
EOS

# Droplet for sudoers
install -d -m 750 %{buildroot}/%{_sysconfdir}/sudoers.d
echo "%"%{admin_group}"  ALL = (%{runas_user}) NOPASSWD:/usr/sbin/fetchnews" \
    > %{buildroot}%{_sysconfdir}/sudoers.d/leafnode

%pre
%service_add_pre leafnode.service leafnode.socket leafnode@.service leafnode-daily.service leafnode-hourly.service leafnode-daily.timer leafnode-hourly.timer

# create daemon group, if not existing
getent group %{runas_group} >/dev/null || groupadd -r %{runas_group}  2>/dev/null || :
getent group %{admin_group} >/dev/null || groupadd -r %{admin_group}  2>/dev/null || :
# create daemon user, if not existing
getent passwd %{runas_user} >/dev/null || \
    useradd -r -g %{runas_group} -s /bin/false -c "leafnode daemon" \
        -d %{spooldir} %{runas_user}  2>/dev/null || :
getent passwd %{admin_user} >/dev/null || \
    useradd -r -g %{admin_group} -s /bin/false -c "leafnode administration" \
        -d %{spooldir} %{admin_user}  2>/dev/null || :
# if postfix is installed
test -x /sbin/postdrop && usermod -a -G maildrop %{runas_user}
exit 0

%post
%set_permissions %{spooldir}/leaf.node
%service_add_post leafnode.service leafnode.socket leafnode@.service leafnode-daily.service leafnode-hourly.service leafnode-daily.timer leafnode-hourly.timer

%preun
%service_del_preun leafnode.service leafnode.socket leafnode@.service leafnode-daily.service leafnode-hourly.service leafnode-daily.timer leafnode-hourly.timer

%postun
%service_del_postun leafnode.service leafnode.socket leafnode@.service leafnode-daily.service leafnode-hourly.service leafnode-daily.timer leafnode-hourly.timer

%files
%license COPYING COPYING.LGPL
%doc config.example filters.example CREDITS README-SUSE.md
%doc DEBUGGING ENVIRONMENT FAQ.tex CHANGES-FROM-LEAFNODE-1 NEWS
%doc README-FQDN.tex TODO ChangeLog AUTHORS README-leaf.node README.html
%attr(644,root,root) %{_unitdir}/%{upname}*
%dir %{_sysconfdir}/leafnode/
%config(noreplace) %attr(640,root,news) %{_sysconfdir}/leafnode/config
%config(noreplace) %attr(640,root,news) %{_sysconfdir}/leafnode/uucp
%config(noreplace) %attr(640,root,news) %{_sysconfdir}/leafnode/local.groups
%dir %{_sysconfdir}/sudoers.d
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/sudoers.d/leafnode
%attr(755,root,root) %{_bindir}/leafnode-version
%attr(755,root,root) %{_bindir}/lsmac.pl
%attr(755,root,root) %{_bindir}/newsq
%attr(755,root,root) %{_sbindir}/applyfilter
%attr(755,root,root) %{_sbindir}/checkgroups
%attr(755,root,root) %{_sbindir}/fetchnews
%attr(755,root,root) %{_sbindir}/leafnode
%attr(755,root,root) %{_sbindir}/rnews
%attr(755,root,root) %{_sbindir}/sendbatch.bash
%attr(755,root,root) %{_sbindir}/texpire
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%attr(775,%{runas_user},%{runas_group}) %{spooldir}

%changelog
* Wed Apr 23 2025 mcepl@cepl.eu
- Update to version 2.0.0~git.1745443528.0925b70:
  * lsmac.pl: Add shebang magic from the perlrun man page
* Wed Apr 23 2025 Matej Cepl <mcepl@cepl.eu>
- Update to version 2.0.0~git.1745442129.6d0967c:
  * configure.ac: Correct missing pandoc value to 'false'
* Wed Apr 23 2025 Matej Cepl <mcepl@cepl.eu>
- Update to version 2.0.0~git.1745441740.a8cac4f:
  * Ship new README.md in 'make dist'.
  * doc: convert README to Markdown
  * NEWS: Add date line so that make distcheck passes.
  * podman test: install PCRE2 dev, avoid interactive input.
  * Bump version.
  * configure.ac: clean up
  * Fix type width for %%*s argument to ln_log().
  * Complete PCRE2 conversion. Untested.
  * Fix configure.ac to properly detect PCRE2.
  * WIP: port to PCRE-2
  * Use proper mid-index calculation avoiding integer overflow.
  * Hook up bsearch_range tests.
  * Return an empty line alone, at end of header.
* Sat Mar 22 2025 mcepl@cepl.eu
- Update to version 2.0.0+git.1722082987.9543ffa:
  * Use proper mid-index calculation avoiding integer overflow.
  * Hook up bsearch_range tests.
  * Return an empty line alone, at end of header.
  * Add a test program to help debug mastr_getfoldedln().
  * Force C linkage in some of our headers under C++.
  * Update
  * switch dist format from .tar.bz2 to .tar.xz
  * Add missing prototype for nntpdisconnect()
  * Add a script to test build on Debian's testing.
  * sa2addr: convert to getnameinfo
  * Fix masock_*.c warnings, and properly decode hostnames.
- Switch README-SUSE from reStructuredText to Markdown
- Add convert-to-PCRE2.patch porting whole program to use pcre2
  instead of pcre (bsc#1239931).
* Mon Mar  6 2023 Matej Cepl <mcepl@suse.com>
- User news must be in maildrop group (if postfix has been
  installed).
* Sat Mar  4 2023 mcepl@suse.com
- Update to version 2.0.0+git.1677927696.44d2783:
  * configure.ac: add PCRE to LIBS not LDCONFIG
  * Make C++17 compatible.
  * Add a comment about rnews.
  * Plug memory leak.
  * Update NEWS and ChangeLog.
  * store: cope with folded headers.
  * Bump copyright.
  * split_serverarg(): initialize char *s[3].
  * log_fclose: fix use-after-free warning
  * ugid.h: fix Linux features.h compiler warning
  * configure.ac: update and bump version
  * newsq: Plug memory leaks.
* Tue May 17 2022 mcepl@suse.com
- Update to version 2.0.0+git.1625851959.1275fbe:
  * Bump version and update NEWS.
  * Ship Matěj Cepl's systemd files, and refer to them
  * Replace /etc/cron.daily/leafnode with systemd timer
- Remove upstreamed patches:
  - systemd-timers.patch
* Mon Oct  4 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_leafnode@.service.patch
* Fri Jul  9 2021 Matej Cepl <mcepl@suse.com>
- It is not necessary to manually set rights and ownership on
  %%{spooldir}, and it prevents a security issue (bsc#1159996).
* Sat Jun  6 2020 Matej Cepl <mcepl@suse.com>
- Add sudoers droplet to allow users in newsadmin group to
  run fetchnews.
* Mon Jun  1 2020 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Wed Dec  4 2019 Matej Cepl <mcepl@suse.com>
- Add Conflicts: inn, because of conflicting moderators(5)
  manpage and really, these shouldn't be on one system together.
* Mon Nov 18 2019 Matej Cepl <mcepl@suse.com>
- Replace leafnode-1 with leafnode-2 (original leafnode-2
  changelog is interspersed among the records of this changelog).
  Details of the change are available in the file
  CHANGES-FROM-LEAFNODE-1 packaged as a documentation file within
  the package.
- Add README-SUSE.rst for more information on the status of the
  package in the openSUSE world.
- Add systemd-timers.patch to switch from cron to systemd-timers
  (bsc#1115443)
- Remove leafnode-1.11.6-spooldir-permissions.diff patch which is
  not relevant for the rebased leafnode.
* Mon Nov 11 2019 Matej Cepl <mcepl@suse.com>
- Remove support for cron and xinetd
- Silence rpmlint
* Wed Nov  6 2019 matthias.gerstner@suse.com
- add patch fix_overflow.diff: fixes potential stack buffer overflow if
  unexpected directories with high numbers as a prefix appear. This is only a
  hardening.
* Tue Aug 20 2019 kukuk@suse.de
- BuildRequire cron since it contains now the cron directories
- Use %%license instead of %%doc [bsc#1082318]
* Sun May 27 2018 mcepl@suse.com
- Clean up SPEC and setup _service, remove unnecessary RHEL/Fedora
  conditionals.
* Sun May 27 2018 opensuse-packaging@opensuse.org
- Update to version 2.0.0+git.1527241185.66da754:
  * Convert manpages to UTF8 and mark them a such.
  * Fixes autotools on systemd-based systems.
  * #define _DEFAULT_SOURCE for newer glibc features.h
  * Avoid crash on missing/empty authentication file.
  * Gitorious -> GitLab.
  * Replace defunct URLs by those that work.
  * Replace COPYING.LGPL with a fresh copy.
  * Apparently leafnode-2 as of now builds with autoconf 2.63
  * Convert to UTF-8. Suggested by Matěj Cepl.
  * Add Lloyd Zusman and Robert Grimm to authors file.
* Fri Mar 16 2018 mcepl@redhat.com
- Port to OpenSUSE (as well)
* Fri Jun 16 2017 aliouliaki@suse.com
- Removed xinetd service
- Added leafnode@.service and leafnode.socket
- Clean up of leafnode.spec file
* Tue Nov 22 2016 mcepl@redhat.com
- systemd unit files are not executable anymore
- rebase on the top of the upstream Gitlab checkout.
* Tue Aug 25 2015 astieger@suse.com
- leafnode 1.11.11:
  * The configfile parser now strips whitespace between a
    configuration parameter's value and a trailing comment.
  * The roff manual page sources now render proper hyphens (-),
    minus characters (\-) and en-dashes (\[en]) depending on
    their context. This is so that copying-and-pasting from the
    manual page works properly.
  * The code that checks if the peer is local now properly deals
    with IPv4 mapped IPv6 addresses.
* Tue Mar 24 2015 astieger@suse.com
- format spec file, remove gpg-offline fixing SLE 12 build
* Thu Jan  8 2015 mcepl@redhat.com
- Make cronjobs into proper scripts and add proper configuration
  file.
* Mon Dec 29 2014 mcepl@redhat.com
- Add patch converting fetchnews(8) to UTF-8.
* Sat Dec 27 2014 mcepl@redhat.com
- Make it buildable on RHEL-6 (apparently just decreasing required
  autoconf is enough).
* Fri Dec 26 2014 mcepl@redhat.com
- Set run_as_user parameter in /etc/leafnode/config explicitly.
* Mon Dec 15 2014 mcepl@redhat.com
- [leafnode 2] Update to the latest upstream
* Thu Jul 24 2014 mcepl@redhat.com
- [leafnode 2] Update to the latest upstream
* Tue Jun 11 2013 andreas.stieger@gmx.de
- 1.11.10 - no user visible changes
  * source changes affecting build system and portablility
  * fixes an abort in verbose mode when running fetchnews 1.11.9
- 1.11.9 - no user visible changes
  * source changes affecting build system and compiler warnings
- packaging changes:
  * require pcre >= 2.06
  * droped leafnode-1.11.8-gethostbyname-2-getaddrinfo.patch :
    accepted upstream
  * verify source signature
* Mon Jan 14 2013 andreas.stieger@gmx.de
- reformat spec file, licence is LGLP-2.1+, remove INSTALL
* Sun Sep 25 2011 andreas.stieger@gmx.de
- update list of authors to include current maintainer
* Thu Aug 18 2011 boris@steki.net
- add patch for getaddrinfo
* Sat Jul 30 2011 andreas.stieger@gmx.de
- update to upstream 1.11.18
  * 1.11.8, 2010-06-12
  [#]## BUGFIXES
- Performance optimization, reported by Gary R. Schmidt.
- Fix a compiler warning on computers where "long" is a wider type than "int",
  such as many 64-bit computers.
- Fix compiler warnings on computers where "long" is a wider type than
  "time_t", such as NetBSD 5.X on 64-bit computers.
- Fix compiler warning "dereferencing type-punned pointer will break
  strict-aliasing rules"
- Fix a file descriptor leak in fetchnews.c's getbody_newno function; reported
  to Debian BTS by Helmut Grohne, fix by Robert Grimm.
  [#]## CHANGES
- Leafnode now enables IPv6 support by default. Use --without-ipv6 to disable.
- Leafnode now supports detecting if a peer is in a local network also
  for IPv6 global addresses, providing that the host OS provides getifaddrs().
  This comprises Linux, NetBSD, FreeBSD, but not, for instance, Solaris 10.
  Reported missing by M. G. Berberich.
- Leafnode is now always compiled in maintainer mode.
  This has no impact on run-time behaviour.
- Leafnode now assumes that handlers for signal() do not return a value.
  [#]## WORKAROUND
- Skip arbitrary amounts of contiguous CR right before LF. Reported by John R.
  Myers.
  [#]## DOCUMENTATION
- Remove the long-obsoleted README.FIRST file.
- The FAQ has information on how to copy the spool.
- FAQ: The MAC OS X two-level namespace documentation for PCRE was removed,
  PCRE is no longer part of the leafnode distribution.
- FAQ: mention how to fix losing unsubscriptions of low-traffic groups in slrn
- config.example: The expire documentation should now be clearer and closer to
  the one in the leafnode(8) manual page. Along the lines discussed by Chris G
  and Whiskers on the leafnode mailing list.
  * 1.11.7, 2009-04-20
  [#]## WORKAROUND
- fetchnews: If the LN_SUPPRESS_DATE environment variable is defined and set
  to any value or empty, fetchnews will not test the upstream server's time by
  means of the "DATE" NNTP command.
  This can be used to quench related log messages.
  [#]## BUGFIXES
- Fix logging if texpire unlinks files without further hardlinks from
  message.id/NNN/
- Fix potential segfault on libcs that do not catch NULL for %%s formatting
  (several GNU libc versions do) when trying to retrieve delayed bodies from
  corrupt article headers. Pretend success, to purge article number from
  subscription file.  Bug reported by Chris Carr.
- Fix & change "noactive" so that it can be overridden by "fetchnews -f", as
  documented in config.example.
  Regression as side effect of 1.9.50 fix, reported by Jesse F. Hughes.
- Fix logged IP address in "connected to..., reply:" message when compiled
  without IPv6 support.
  Fixes Mandriva Bug #45605, reported by David W. Hodgins.
- Print connected to... to console as well at proper verbosity level, found
  by maintainer while debugging aforementioned bug.
- Only emit warning that no server with posting permission was found if that's
  actually needed. Reported by Christian Weiske.
- If corrupted articles had been detected, fetchnews -x NNN would not be able
  to re-fetch the said article because a 0-sized file remained in message.id,
  making fetchnews believe the article was in the spool.
  0-sized message.id/NNN/ files are now purged when checking if the article is
  already in the spool.
  Reported by Peter Bauernfeind. (de.comm.software.newsserver post, May 2008)
- Change interface enumeration to track incompatible NetBSD 5 changes.  The
  latter led to bogus connection refusals in NNTPD.  SourceForge Bug #2700756,
  by Aleksey Cheusov, fix suggested by Roy Marples.
- Add support for SIOCGIFALIAS where available (BSD) in order to obtain
  netmasks for 4.4BSD-style IP aliases.
  getifaddrs() has been suggested as well, but it isn't available everywhere,
  so we would have to keep the old code around anyways, and we can just fix
  that rather than introduce alternative code branches.
  [#]## BUGFIXES BACKPORTED FROM LEAFNODE 2
- lsort (used by make update) now detects and report errors.
- "make update" handles the lockfile properly now: it records its PID and
  removes the lock also in cases of failure.
- "make update" restores the old groupinfo file if lsort fails.
- "make update" now builds an up-to-date lsort first.
- "make update" now uses the configured NEWS_USER and _GROUP.
- "make update" is now a phony Makefile target, i. e. it will work even
  if there is a file "update" in the build directory.
  [#]## CHANGES
- When creating a Path: header (because the newsreader did not do that), use
  "not-for-mail" instead of NEWS_USER (usually "news") as the user component.
  This seems to resolve propagation issues with 2nd-hop-upstreams, as reported
  in Debian Bug#459980 by Michael Weitzel, with Universität Siegen, Germany.
- When writing to client fails, log decoded errno, too.
  This can help debugging certain firewall misconfigurations more easily.
- Undoing a wordwrap in configure.ac allows for bootstrapping on Cygwin.
- Drop obsolete mysetvbuf().
- leafnode-version now supports an additional "-v" mode to print more
  information on the installation. The output then is similar, but not
  identical - due to different feature sets - to the way leafnode-2 prints it.
  [#]## DOCUMENTATION
- Add some comments to UNINSTALL-daemontools
- Put README-FQDN* under leafnode's license. Found to be in conflict with
  Debian's DFSG by Mark Brown.
* Sat Jul 30 2011 andreas.stieger@gmx.de
- resurrect package from discontinued 11.1
- move make check to %%check section to fix rpmlint warning
- adjust %%install section to not clean out doc_german too much to make %%check work
- adjust %%files section to name files in doc_german individually
- add %%config to config.example to fix rpmlint warning
* Thu May  8 2008 seife@suse.de
- add an example crontab to fetch news every hour (bnc #382542)
* Wed Apr  9 2008 crrodriguez@suse.de
- leafnode does not remove old news threads without cron which is
  not installed by default now
* Tue Jun  5 2007 seife@suse.de
- add leafnode-1.11.6-spooldir-permissions.diff, bug 273929
- add some tricks to get the package past the rpmlint censors
* Wed May 23 2007 mcepl@redhat.com
- [leafnode 2] Added support for croning of texpire daily
* Thu Apr 26 2007 mcepl@redhat.com
- [leafnode 2] Add pcre-devel to Build-Requires; thanks
  build.opensuse.org for catching this.
- Add /etc/leafnode/local.groups
* Fri Mar 23 2007 mcepl@redhat.com
- [leafnode 2] new upstream release
- enabled pam
* Wed Mar 21 2007 seife@suse.de
- Update to version 1.11.6:
  * do not delete articles if References: lines are malformatted
  * fix compilation with SGI IDO cc
  * reject *.site fqdn.
  * documentation fixes
  * support autoconf 2.60, fixing datarootdir-related warnings
* Tue Nov  7 2006 meissner@suse.de
- fixed use of RPM_OPT_FLAGS
* Mon Sep  4 2006 seife@suse.de
- Update to version 1.11.5:
  * applyfilter overhaul
  * fetchnews: Keep non-expiring groups (negative groupexpire date)
    active, even if they expired upstream. sf.net bug#1230256
  * some loglevel adjustments
  * fetchnews: Do not mark the active for refetch when the failed
    server has "noread" set or fetchnews is in -P (post only) mode.
  * fetchnews: Skip to next server if posting fails.
  * fetchnews: Don't POST if the server goes away after STAT.
  * various documentation fixes
- clean up pakaged documentation
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Mon Jan  2 2006 mcepl@redhat.com
- [leafnode 2] experimental build
* Fri Oct 28 2005 ro@suse.de
- work around strange behaviour of "mkdir -p .../."
* Mon Jun 13 2005 rommel@suse.de
- update to version 1.11.3.rel (fixes bug #88489 and #83355)
* Thu Sep  2 2004 mmj@suse.de
- Remove update messages, since the versions that could trigger
  them haven't been in the distribution since +2 years [#44363]
* Sat Aug  7 2004 rommel@suse.de
- update to version 1.10.3.rel
* Mon Jun 28 2004 rommel@suse.de
- update to version 1.10.1.rel
* Thu Apr 15 2004 rommel@suse.de
- update to version 1.9.52.rel (security fix, bug #38905)
* Wed Mar  3 2004 rommel@suse.de
- update to version 1.9.51.rel (bugfix release for reliable groupinfo file
  detection)
* Mon Feb 16 2004 rommel@suse.de
- update to version 1.9.49.rel
- reworked inetd/xinetd section in README.SuSE
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Jul  9 2003 rommel@suse.de
- update to version 1.9.42.rel
- added doc_german directory to /usr/share/doc/packages/leafnode
* Fri Jun 13 2003 mmj@suse.de
- Remove files we don't want to package
- Package some extra ones
* Thu Mar  6 2003 rommel@suse.de
- added a configuration file for xinetd
* Thu Feb 13 2003 rommel@suse.de
- update to version 1.9.33.rel
  (fixes some bugs, enhances compatiblity with versions older
  than 1.9.23 and adds a per-server noread flag)
* Fri Jan 17 2003 rommel@suse.de
- update to version 1.9.32.rel
- added "make check" to build section
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug 16 2002 rommel@suse.de
- Added PreReq:
* Fri Jul 26 2002 rommel@suse.de
- Update to 1.9.24.rel
- Updated README.SuSE
- Updated list of authors
* Thu Apr 25 2002 rommel@suse.de
- Update to 1.9.22
- Fixed permissions of /etc/leafnode
  (thanks to matthias.andree@gmx.de)
* Tue Feb 19 2002 grimmer@suse.de
- Updated README.SuSE to reflect 8.0 changes (thanks to Ulrich
  Mindrup for reminding me) (#13554)
* Wed Jul 11 2001 grimmer@suse.de
- Update to 1.9.19 (bugfix release)
- added "su - news -c" to texpire call in daily cron job
* Wed May  2 2001 grimmer@suse.de
- added check for existing groupinfo file to cron job
  to avoid unnecessary junk mail to root if fetchnews has
  not been run yet (#7457)
- minor changes to README.SuSE
* Sun Feb 11 2001 grimmer@suse.de
- added /etc/cron.daily/leafnode to expire old articles
  (obsoletes the entry in /etc/crontab) (#6259)
* Tue Dec  5 2000 grimmer@suse.de
- Update to 1.9.18 (bugfix release)
- bzipped sources
- removed README.SuSE from patch and added as a separate
  source file instead
* Thu Oct  5 2000 grimmer@suse.de
- Update to 1.9.17 (bugfixes)
- corrected a path name in README.SuSE
- specfile correction: only send mail to root, if
  there was an update from a very old version
* Tue Aug  8 2000 grimmer@suse.de
- Update to 1.9.15
* Mon Jun 19 2000 grimmer@suse.de
- Update to 1.9.14
* Thu Mar 30 2000 grimmer@suse.de
- Update to 1.9.12 (bugfixes)
* Thu Feb 24 2000 grimmer@suse.de
- Update to 1.9.11 (bugfixes)
* Sun Feb 20 2000 grimmer@suse.de
- patched Makefile.in to actually use mandir
* Thu Feb 17 2000 grimmer@suse.de
- update to 1.9.10
- spec file cleanups
- added Group Tag and URL
- added german documentation and man pages
- use version and mandir macro in spec file
- marked config files as "noreplace"
* Tue Nov 23 1999 grimmer@suse.de
- Added Y2K patch to nntpd.c
* Sat Oct  2 1999 grimmer@suse.de
- added Provides nntp_daemon to specfile
- modified update notice
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  2 1999 grimmer@suse.de
- update to 1.9.4
- added update.sh to $DOCDIR and adjusted README.SuSE
- fetch is now called fetchnews
* Tue Apr 27 1999 ro@suse.de
- configure: hardcoded paths for RPM: detections breaks with rpm-3.0
* Wed Mar 10 1999 grimmer@suse.de
- Updated specfile to send mail to root when updating from previous
  releases
- created sample filter configuration file
* Thu Mar  4 1999 grimmer@suse.de
- update to Version 1.9.2
- now uses /etc/leafnode for configuration files
- changed permissions of /etc/leafnode/config (security reasons)
- now uses /var/lock/news for locking instead of /var/run
* Tue Feb 16 1999 grimmer@suse.de
- update to Version 1.9
- now uses GNU autoconf
* Thu Jan 28 1999 grimmer@suse.de
- update to Version 1.8.1
* Thu Dec 10 1998 grimmer@suse.de
- update to Version 1.7.1
* Tue Nov 10 1998 grimmer@suse.de
- New package (Version 1.6.2)
